==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/vins/data_vins_list_deleted/main.tf <==
/*
Пример использования
Получение списка удаленных vins
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_vins_list_deleted" "vins_list_deleted" {
  #фильтр по id vins
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка балансировщиков нагрузки
  #опциональный параметр
  #тип - целое число
  #account_id = 11111

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 100

  #фильтр по IP внешней сети
  #опциональный параметр
  #тип - строка
  #ext_ip = "test"

  #фильтр по id vnfDevices
  #опциональный параметр
  #тип - целое число
  #vnfdev_id = 11111

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #кол-во страниц для вывода
  #опциональный параметр
  #тип - целое число
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #size = 1
}

output "test" {
  value = data.dynamix_vins_list_deleted.vins_list_deleted
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/vins/data_vins_list_deleted/main.tf <==
/*
Пример использования
Получение списка удаленных vins
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_vins_list_deleted" "vins_list_deleted" {
  #фильтр по id vins
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени vins
  #опциональный параметр
  #тип - строка
  #name = "test"

  #id аккаунта для получения списка балансировщиков нагрузки
  #опциональный параметр
  #тип - целое число
  #account_id = 11111

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - целое число
  #rg_id = 100

  #фильтр по IP внешней сети
  #опциональный параметр
  #тип - строка
  #ext_ip = "test"

  #фильтр по id vnfDevices
  #опциональный параметр
  #тип - целое число
  #vnfdev_id = 11111

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #кол-во страниц для вывода
  #опциональный параметр
  #тип - целое число
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - целое число
  #size = 1
}

output "test" {
  value = data.dynamix_vins_list_deleted.vins_list_deleted
}
